aboutsummaryrefslogtreecommitdiffstats
path: root/hicn-plugin/src/interest_pcslookup.h
diff options
context:
space:
mode:
Diffstat (limited to 'hicn-plugin/src/interest_pcslookup.h')
-rw-r--r--hicn-plugin/src/interest_pcslookup.h24
1 files changed, 17 insertions, 7 deletions
diff --git a/hicn-plugin/src/interest_pcslookup.h b/hicn-plugin/src/interest_pcslookup.h
index cbc9dde51..ba0e7651d 100644
--- a/hicn-plugin/src/interest_pcslookup.h
+++ b/hicn-plugin/src/interest_pcslookup.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017-2019 Cisco and/or its affiliates.
+ * Copyright (c) 2021 Cisco and/or its affiliates.
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at:
@@ -24,12 +24,12 @@
/**
* @file interest_pcslookup.h
*
* This is the node encoutered by interest packets after the hicn6-iface-input or
* hicn4-iface-input. This node performs a lookup in the pit and content store and
* if there is a hit in the PIT, the vlib buffer is passed to the hicn-interest-hitcs
* while if there is a hit in the CS the vlib buffer is passed to the
* hicn-interest-hitpit. If there isn't any hit, the vlib buffer is passed to the
* hicn-strategy node.
*/
/*
@@ -58,6 +58,16 @@ typedef enum
HICN_INTEREST_PCSLOOKUP_N_NEXT,
} hicn_interest_pcslookup_next_t;
+typedef enum
+{
+ HICN_INTEREST_MANIFEST_PCSLOOKUP_NEXT_FACE4,
+ HICN_INTEREST_MANIFEST_PCSLOOKUP_NEXT_FACE6,
+ HICN_INTEREST_MANIFEST_PCSLOOKUP_NEXT_INTEREST_HITPIT,
+ HICN_INTEREST_MANIFEST_PCSLOOKUP_NEXT_INTEREST_HITCS,
+ HICN_INTEREST_MANIFEST_PCSLOOKUP_NEXT_ERROR_DROP,
+ HICN_INTEREST_MANIFEST_PCSLOOKUP_N_NEXT,
+} hicn_interest_manifest_pcslookup_next_t;
+
#endif /* // __HICN_INTEREST_PCSLOOKUP_H__ */
/*
@@ -24,12 +24,12 @@
* @file interest_pcslookup.h
*
- * This is the node encoutered by interest packets after the hicn6-iface-input or
- * hicn4-iface-input. This node performs a lookup in the pit and content store and
- * if there is a hit in the PIT, the vlib buffer is passed to the hicn-interest-hitcs
- * while if there is a hit in the CS the vlib buffer is passed to the
- * hicn-interest-hitpit. If there isn't any hit, the vlib buffer is passed to the
- * hicn-strategy node.
+ * This is the node encoutered by interest packets after the hicn6-iface-input
+ * or hicn4-iface-input. This node performs a lookup in the pit and content
+ * store and if there is a hit in the PIT, the vlib buffer is passed to the
+ * hicn-interest-hitcs while if there is a hit in the CS the vlib buffer is
+ * passed to the hicn-interest-hitpit. If there isn't any hit, the vlib buffer
+ * is passed to the hicn-strategy node.
*/
/*